#!/bin/bash
set -e

series=$1

name=$series-dev

function cleanup {
  lxc delete $name --force
}

function on_err {
  echo -e "Test Failed"
  cleanup
  exit 1
}
trap on_err ERR


lxc launch ubuntu-daily:$series $name
sleep 5

# Install latest ubuntu-advantage-tools
lxc exec $name -- apt-get update > /dev/null
lxc exec $name -- apt-get install  -y ubuntu-advantage-tools > /dev/null
echo -e "\n* Latest u-a-t is installed"
echo "###########################################"
lxc exec $name -- apt-cache policy ubuntu-advantage-tools
echo -e "###########################################\n"


# Upgrade u-a-t to new version
# ----------------------------------------------------------------
lxc exec $name -- sh -c "echo \"deb http://archive.ubuntu.com/ubuntu $series-proposed main\" | tee /etc/apt/sources.list.d/proposed.list"
lxc exec $name -- apt-get update > /dev/null
lxc exec $name -- sh -c "cat > /etc/apt/preferences.d/pro-posed << EOF
Package: ubuntu-advantage-tools ubuntu-pro-client ubuntu-pro-auto-attach ubuntu-advantage-pro ubuntu-pro-client-l10n
Pin: release a=$series-proposed
Pin-Priority: 600
EOF"
lxc exec $name -- apt-get install ubuntu-advantage-tools -y > /dev/null
# ----------------------------------------------------------------

echo -e "\n* Installed u-a-t from -proposed"
echo "###########################################"
lxc exec $name -- apt-cache policy ubuntu-advantage-tools ubuntu-pro-client
echo -e "###########################################\n"

# Show esm-infra-legacy when unattached
# ----------------------------------------------------------------
echo -e "\n* Show esm-infra-legacy on status when unattached"
echo "###########################################"
lxc exec $name -- sudo ua status
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Attach u-a-t to token with esm-infra-legacy support
# ----------------------------------------------------------------
echo -e "\n* Attaching to license entitled to esm-infra-legacy"
echo "###########################################"
lxc exec $name -- sudo sed -i 's/contracts.can/contracts.staging.can/' /etc/ubuntu-advantage/uaclient.conf
lxc exec $name -- sudo ua attach $UACLIENT_BEHAVE_CONTRACT_TOKEN_STAGING
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Enabling esm-infra-legacy
# ----------------------------------------------------------------
echo -e "\n* Enabling esm-infra-legacy service"
echo "###########################################"
lxc exec $name -- sudo ua enable esm-infra-legacy
lxc exec $name -- ua status
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Show APT repo in apt-cache policy
# ----------------------------------------------------------------
echo -e "\n* Show APT esm-infra-legacy repos on the machine"
echo "###########################################"
lxc exec $name -- sh -c "apt-cache policy | head -n 20"
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Disable esm-infra-legacy service
# ----------------------------------------------------------------
echo -e "\n* Disable esm-infra-legacy servicee"
echo "###########################################"
lxc exec $name -- sudo ua disable esm-infra-legacy
lxc exec $name -- ua status
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Show APT repo not in apt-cache policy
# ----------------------------------------------------------------
echo -e "\n* Show APT esm-infra-legacy repos not on the machine"
echo "###########################################"
lxc exec $name -- sh -c "apt-cache policy | head -n 20"
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Enabling esm-infra-legacy again
# ----------------------------------------------------------------
echo -e "\n* Enabling esm-infra-legacy service again"
echo "###########################################"
lxc exec $name -- sudo ua enable esm-infra-legacy
lxc exec $name -- ua status
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Run detach
# ----------------------------------------------------------------
echo -e "\n* Run detach"
echo "###########################################"
lxc exec $name -- sh -c "yes y | sudo ua detach"
lxc exec $name -- ua status
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Attach u-a-t to token without esm-infra-legacy support
# ----------------------------------------------------------------
echo -e "\n* Attaching to license not entitled to esm-infra-legacy"
echo "###########################################"
lxc exec $name -- sudo sed -i 's/contracts.staging.can/contracts.can/' /etc/ubuntu-advantage/uaclient.conf
lxc exec $name -- sudo ua attach $UACLIENT_BEHAVE_CONTRACT_TOKEN
echo -e "###########################################\n"
# ----------------------------------------------------------------

# Run detach
# ----------------------------------------------------------------
echo -e "\n* Run detach"
echo "###########################################"
lxc exec $name -- sh -c "yes y | sudo ua detach"
lxc exec $name -- ua status
echo -e "###########################################\n"
# ----------------------------------------------------------------

cleanup
